# User Manual: 3D Slicer Module for Verifying Aneurysm Detections
This user manual describes a 3D Slicer module designed to verify aneurysm detections generated by deep learning models. Each detection corresponds to a sphere defined by its center (x, y, z), radius (mm), and a confidence score (%) that indicates the likelihood of it being a true aneurysm.

The manual is divided into two main sections. The first section covers the installation and configuration of the 3D Slicer software and the extension. The second section focuses on the tool's functionalities and provides a step-by-step guide to using the different components for verifying aneurysm detections.

# Main Module Window
<img src="Images/sample.gif" alt="Main module view">

# Getting Started 
## Prerequisites
- 3D Slicer version 4.11 or later.

## Installation
To use this module, you will need to have 3D Slicer version 4.11 or later installed on your machine. You can download the latest version of 3D Slicer from the [official website](https://download.slicer.org/). Once installed, the software's main interface can be accessed.

To install the check detections module, follow these steps:
1. Download the module from the official repository [Here](https://gitlab.inria.fr/yassis/slicercheckdetections/-/archive/v1.0.0/slicercheckdetections-v1.0.0.zip) or using the following command line:
    ```
    git clone https://gitlab.inria.fr/yassis/slicercheckdetections.git
    ```
2. Open 3D Slicer.
3. Go to the Application Settings (in the "Edit" menu).
4. Go to the "Module" tab.
5. Add the module path in the "Additional module paths".
6. Press OK. Slicer will need to be restarted.

<img src="Images/step2.png" alt="Configuration steps">

# Description 
## Data Description
The purpose of this tool is to allow the verification of aneurysm detections for several patients. For this, the data is organized by patient, each of them corresponding to a folder containing two files: a 3D volume file in (.nii.gz) format, and a file (.json) containing the detections for this patient. This organization allows easy access to the data of each patient and verification of the detections. It is important to note that when a patient has been verified by the user (e.g. radiologist), they will automatically be moved to a new folder named ***Done*** which is located in the same main folder. This keeps the data organized and shows which patients have already been checked by the user.

## Access to the Module
To access the module from the main interface of 3D Slicer, you can use the quick access bar (indicated by the green arrow in figure below) or find the module in the list of modules by clicking on the ”Welcome to Slicer” button and selecting ”Check detections” (steps 1 and 2).

<img src="Images/step3.png" alt="Access steps">

## Module Description
The module's main interface is shown in the figure below. It is divided into two parts. The first part allows to load and manipulate the input data (the 3D volume and the detections), while the second part is mainly dedicated to the visualization and the verification of the detections in an individual way. 

<img src="Images/exemple.png" alt="Main module view">

Each component of the interface is identified by a number, and its operation is explained in detail below.
1. The Load button allows you to load a patient by selecting the corresponding folder. The module will automatically load the detections (if any) and display the 3D volume of the patient in the 3D, axial, sagittal and coronal views.
2. The "Visibility" checkbox is used to control the visibility of the volume in the 3D view. By clicking on this box, you can show or hide the volume in the 3D view, which can be useful to better visualize the detections.
3. The "Threshold" slider lets you apply thresholding to the volume in the 3D view.
4. Controls the opacity of the volume in the 3D view.
5. Enable/Disable the visibility of detections in the 3D view. By default, no detection is displayed: the first step is to diagnose aneurysms, without a priori detection. This will make it easier to note undetected aneurysms.
6. Shows or hides the confidence scores of the detections in the 3D view.
7. Displays only the vicinity of the current detection, inside a selection box.
8. Controls the opacity of detections in the 3D view.
9. Table to display information about each detection: confidence score, radius, color. To view each detection separately, the user must click on the line of the table that corresponds to the detection in question. Automatically, the module removes all the other detections from the 3D view, and the three other views (axial, sagittal, coronal) are centered on the detection concerned. After verification of this detection, the user must decide whether it is indeed a real aneurysm or not, by checking the associated box in the "Aneurysm?" column. If the user has a doubt about the proposed detection, he can check the box in the "Doubt?" column. The principle is that when the user considers that an automatic detection software must indicate such an area for review, then the column must be checked.
10. A free text field allows you to add notes concerning the patient in question, for example if he has an undetected aneurysm. These notes will be saved in a file called $description.txt$ to be consulted and analyzed later.
11. Once the user has checked all the proposed detections, it is mandatory to save his decisions to keep them. A new file called '_output.json' will be created in the patient folder. It is important to emphasize that the user can at any time reload the data of a patient that he has previously checked. Its decisions will be automatically reloaded and displayed in the table to facilitate the verification work. This feature is useful when the user wants to review their previous choices or need to update them.

## Usage  
For each patient:
1. Load patient data (Load button).
2. adjust the 3D view (threshold and opacity).
3. do an initial review to see where the potential aneurysms are.
4. make the detections visible (box “Visibility”): There may be no detection. This may be the case if the detection failed or simply because the patient is a healthy patient.
5. review each detection (table): note whether it is an aneurysm or not if you have any doubts.
6. If necessary, add a note on an undetected aneurysm (number and locations).
7. save.
8. go to the next patient (back to step 1).

## Features
This Slicer "Check Dectections" module includes the following features:
- Intuitive user interface for easy verification of aneurysms.
- Ability to adjust the visibility and color of volume and detections (spheres) to highlight the location of the aneurysm.
- Ability to save and load decisions for later use.
- Can be adapted and used in a clinal settings.

## Citation
If you find this repository useful for your work, please consider citing our paper: 
```
[Assis et al. 2023] coming soon.
```

## Contact
If you have any questions or feedback about this module, please contact me by email (youssef.assis@loria.fr).

## License
This project is licensed under the MIT License. This license allows for free use, modification, and distribution of the code, as long as the original license and copyright notice are included in any copies or derivatives.
